/* BDF - Copyright (c) 2018-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.commands;

import java.util.HashMap;
import java.util.Map;
import java.util.function.Predicate;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.SubsetKey;
import net.fichotheque.corpus.Corpus;
import net.fichotheque.eligibility.SubsetEligibility;
import net.fichotheque.utils.EligibilityUtils;


/**
 *
 * @author Vincent Calame
 */
public class CreationSubsetEligibility implements SubsetEligibility {

    public final static short SUBSET = 1;
    public final static short ITEMS = 2;
    private final Map<SubsetKey, Boolean> subsetMap = new HashMap<SubsetKey, Boolean>();
    private final Map<SubsetKey, Boolean> itemsMap = new HashMap<SubsetKey, Boolean>();
    private final Map<Short, Boolean> categorySubsetMap = new HashMap<Short, Boolean>();
    private final Map<Short, Boolean> categoryItemsMap = new HashMap<Short, Boolean>();

    public CreationSubsetEligibility() {

    }

    public void add(SubsetKey subsetKey, short type, boolean include) {
        switch (type) {
            case SUBSET:
                subsetMap.put(subsetKey, include);
                if (!include) {
                    itemsMap.put(subsetKey, false);
                }
                break;
            case ITEMS:
                itemsMap.put(subsetKey, include);
                break;
        }
    }

    public void add(short category, short type, boolean include) {
        switch (type) {
            case SUBSET:
                categorySubsetMap.put(category, include);
                if (!include) {
                    categoryItemsMap.put(category, false);
                }
                break;
            case ITEMS:
                categoryItemsMap.put(category, include);
                break;
        }
    }

    @Override
    public boolean accept(Subset subset) {
        if (subset instanceof Corpus) {
            Subset masterSubset = ((Corpus) subset).getMasterSubset();
            if (masterSubset != null) {
                if (!accept(masterSubset)) {
                    return false;
                }
            }
        }
        SubsetKey subsetKey = subset.getSubsetKey();
        Boolean b = subsetMap.get(subsetKey);
        if (b != null) {
            return b;
        }
        b = categorySubsetMap.get(subsetKey.getCategory());
        if (b != null) {
            return b;
        }
        return false;
    }

    @Override
    public Predicate<SubsetItem> getPredicate(Subset subset) {
        if (subset instanceof Corpus) {
            Subset masterSubset = ((Corpus) subset).getMasterSubset();
            if (masterSubset != null) {
                if (!hasItems(masterSubset.getSubsetKey())) {
                    return EligibilityUtils.NONE_SUBSETITEM_PREDICATE;
                }
            }
        }
        SubsetKey subsetKey = subset.getSubsetKey();
        if (hasItems(subsetKey)) {
            return EligibilityUtils.ALL_SUBSETITEM_PREDICATE;
        } else {
            return EligibilityUtils.NONE_SUBSETITEM_PREDICATE;
        }
    }

    private boolean hasItems(SubsetKey subsetKey) {
        Boolean b = itemsMap.get(subsetKey);
        if (b != null) {
            return b;
        }
        b = categoryItemsMap.get(subsetKey.getCategory());
        if (b != null) {
            return b;
        }
        return false;
    }

}
