/* BdfServer - Copyright (c) 2007-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.storage;

import fr.exemole.bdfserver.api.storage.BalayageStorage;
import fr.exemole.bdfserver.api.storage.BdfExtensionStorage;
import fr.exemole.bdfserver.api.storage.BdfUserStorage;
import fr.exemole.bdfserver.api.storage.ConfigurationStorage;
import fr.exemole.bdfserver.api.storage.GroupStorage;
import fr.exemole.bdfserver.api.storage.MigrationEngine;
import fr.exemole.bdfserver.api.storage.PasswordStorage;
import fr.exemole.bdfserver.api.storage.PolicyStorage;
import fr.exemole.bdfserver.api.storage.RedacteurListStorage;
import fr.exemole.bdfserver.api.storage.ResourceStorage;
import fr.exemole.bdfserver.api.storage.RoleStorage;
import fr.exemole.bdfserver.api.storage.ScrutariExportStorage;
import fr.exemole.bdfserver.api.storage.SqlExportStorage;
import fr.exemole.bdfserver.api.storage.StorageCheck;
import fr.exemole.bdfserver.api.storage.TableExportStorage;
import fr.exemole.bdfserver.api.storage.TemplateStorage;
import fr.exemole.bdfserver.api.storage.TreeStorage;
import fr.exemole.bdfserver.api.storage.UiStorage;
import java.util.List;
import net.fichotheque.FichothequeEditorProvider;
import net.mapeadores.util.logging.MessageLog;
import fr.exemole.bdfserver.conf.BdfServerDirs;
import fr.exemole.bdfserver.api.storage.StorageRoot;


/**
 *
 * @author Vincent Calame
 */
public class StorageCollection {

    private final BdfServerDirs dirs;
    private StorageCheck bdfStorageCheck;
    private BalayageStorage balayageStorage;
    private TableExportStorage tableExportStorage;
    private TemplateStorage templateStorage;
    private MessageLog initMessageLog;
    private List<ResourceStorage> resourceStorageList;
    private StorageRoot outputStorage;
    private StorageRoot cacheStorage;
    private BdfExtensionStorage bdfExtensionStorage;
    private BdfUserStorage bdfUserStorage;
    private PasswordStorage passwordStorage;
    private SqlExportStorage sqlExportStorage;
    private ScrutariExportStorage scrutariExportStorage;
    private ConfigurationStorage configurationStorage;
    private RoleStorage roleStorage;
    private GroupStorage groupStorage;
    private TreeStorage treeStorage;
    private UiStorage uiStorage;
    private PolicyStorage policyStorage;
    private RedacteurListStorage redacteurListStorage;
    private FichothequeEditorProvider fichothequeEditorProvider;
    private final MultiMigrationEngine multiMigrationEngine = new MultiMigrationEngine();

    public StorageCollection(BdfServerDirs dirs) {
        this.dirs = dirs;
    }

    public BdfServerDirs getBdfServerDirs() {
        return dirs;
    }

    public BalayageStorage getBalayageStorage() {
        return balayageStorage;
    }

    public void setBalayageStorage(BalayageStorage balayageStorage) {
        this.balayageStorage = balayageStorage;
    }

    public TableExportStorage getTableExportStorage() {
        return tableExportStorage;
    }

    public void setTableExportStorage(TableExportStorage tableExportStorage) {
        this.tableExportStorage = tableExportStorage;
    }

    public TemplateStorage getTemplateStorage() {
        return templateStorage;
    }

    public void setTemplateStorage(TemplateStorage templateStorage) {
        this.templateStorage = templateStorage;
    }

    public MessageLog getInitMessageLog() {
        return initMessageLog;
    }

    public void setInitMessageLog(MessageLog initMessageLog) {
        this.initMessageLog = initMessageLog;
    }

    public List<ResourceStorage> getResourceStorageList() {
        return resourceStorageList;
    }

    public void setResourceStorageList(List<ResourceStorage> resourceStorageList) {
        this.resourceStorageList = resourceStorageList;
    }

    public StorageRoot getOutputStorage() {
        return outputStorage;
    }

    public void setOutputStorage(StorageRoot outputStorage) {
        this.outputStorage = outputStorage;
    }

    public StorageRoot getCacheStorage() {
        return cacheStorage;
    }

    public void setCacheStorage(StorageRoot cacheStorage) {
        this.cacheStorage = cacheStorage;
    }

    public BdfExtensionStorage getBdfExtensionStorage() {
        return bdfExtensionStorage;
    }

    public void setBdfExtensionStorage(BdfExtensionStorage bdfExtensionStorage) {
        this.bdfExtensionStorage = bdfExtensionStorage;
    }

    public StorageCheck getStorageCheck() {
        return bdfStorageCheck;
    }

    public void setStorageCheck(StorageCheck bdfStorageCheck) {
        this.bdfStorageCheck = bdfStorageCheck;
    }

    public BdfUserStorage getBdfUserStorage() {
        return bdfUserStorage;
    }

    public void setBdfUserStorage(BdfUserStorage bdfUserStorage) {
        this.bdfUserStorage = bdfUserStorage;
    }

    public PasswordStorage getPasswordStorage() {
        return passwordStorage;
    }

    public void setPasswordStorage(PasswordStorage passwordStorage) {
        this.passwordStorage = passwordStorage;
    }

    public SqlExportStorage getSqlExportStorage() {
        return sqlExportStorage;
    }

    public void setSqlExportStorage(SqlExportStorage sqlExportStorage) {
        this.sqlExportStorage = sqlExportStorage;
    }

    public ScrutariExportStorage getScrutariExportStorage() {
        return scrutariExportStorage;
    }

    public void setScrutariExportStorage(ScrutariExportStorage scrutariExportStorage) {
        this.scrutariExportStorage = scrutariExportStorage;
    }

    public RoleStorage getRoleStorage() {
        return roleStorage;
    }

    public void setRoleStorage(RoleStorage roleStorage) {
        this.roleStorage = roleStorage;
    }

    public GroupStorage getGroupStorage() {
        return groupStorage;
    }

    public void setGroupStorage(GroupStorage groupStorage) {
        this.groupStorage = groupStorage;
    }

    public TreeStorage getTreeStorage() {
        return treeStorage;
    }

    public void setTreeStorage(TreeStorage treeStorage) {
        this.treeStorage = treeStorage;
    }

    public PolicyStorage getPolicyStorage() {
        return policyStorage;
    }

    public void setPolicyStorage(PolicyStorage policyStorage) {
        this.policyStorage = policyStorage;
    }

    public RedacteurListStorage getRedacteurList() {
        return redacteurListStorage;
    }

    public void setRedacteurListStorage(RedacteurListStorage redacteurListStorage) {
        this.redacteurListStorage = redacteurListStorage;
    }

    public FichothequeEditorProvider getFichothequeEditorProvider() {
        return fichothequeEditorProvider;
    }

    public void setFichothequeEditorProvider(FichothequeEditorProvider fichothequeEditorProvider) {
        this.fichothequeEditorProvider = fichothequeEditorProvider;
    }

    public MigrationEngine getMigrationEngine() {
        return multiMigrationEngine;
    }

    public void addMigrationEngine(MigrationEngine migrationEngine) {
        multiMigrationEngine.addMigrationEngine(migrationEngine);
    }

    public ConfigurationStorage getConfigurationStorage() {
        return configurationStorage;
    }

    public void setConfigurationStorage(ConfigurationStorage configurationStorage) {
        this.configurationStorage = configurationStorage;
    }

    public UiStorage getUiStorage() {
        return uiStorage;
    }

    public void setUiStorage(UiStorage uiStorage) {
        this.uiStorage = uiStorage;
    }

}
