/* BdfServer - Copyright (c) 2008-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.ui.dom;

import fr.exemole.bdfserver.api.ui.CommentUi;
import fr.exemole.bdfserver.api.ui.FieldUi;
import fr.exemole.bdfserver.api.ui.IncludeUi;
import fr.exemole.bdfserver.tools.ui.UiComponentsBuilder;
import fr.exemole.bdfserver.tools.ui.components.UiComponentUtils;
import java.util.HashMap;
import java.util.Map;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.html.TrustedHtmlFactory;
import net.mapeadores.util.logging.MessageHandler;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;


/**
 *
 * @author Vincent Calame
 */
public class UiComponentsDOMReader {

    private final UiComponentsBuilder uiComponentsBuilder;
    private final TrustedHtmlFactory trustedHtmlFactory;
    private final MessageHandler messageHandler;
    private final Map<String, CommentUi> commentUiMap = new HashMap<String, CommentUi>();

    public UiComponentsDOMReader(UiComponentsBuilder uiComponentsBuilder, TrustedHtmlFactory trustedHtmlFactory, MessageHandler messageHandler) {
        this.uiComponentsBuilder = uiComponentsBuilder;
        this.messageHandler = messageHandler;
        this.trustedHtmlFactory = trustedHtmlFactory;
    }

    public void readUiComponents(Element element_xml) {
        NodeList liste = element_xml.getChildNodes();
        int length = liste.getLength();
        for (int i = 0; i < length; i++) {
            if (liste.item(i).getNodeType() == Node.ELEMENT_NODE) {
                Element element = (Element) liste.item(i);
                String tagName = element.getTagName();
                if (tagName.equals("metadata")) {
                    readMetadata(element);
                }
            }
        }
        for (int i = 0; i < length; i++) {
            if (liste.item(i).getNodeType() == Node.ELEMENT_NODE) {
                Element element = (Element) liste.item(i);
                String tagName = element.getTagName();
                if (tagName.equals("metadata")) {
                    continue;
                } else if (tagName.equals("comment")) {
                    CommentUi commentUi = UiComponentUtils.readCommentUi(element, trustedHtmlFactory, messageHandler, "comment");
                    if (commentUi != null) {
                        CommentUi existingCommentUi = commentUiMap.get(commentUi.getCommentName());
                        if (existingCommentUi != null) {
                            uiComponentsBuilder.addUiComponent(existingCommentUi);
                        } else {
                            uiComponentsBuilder.addUiComponent(commentUi);
                        }
                    }
                } else if (tagName.equals("field-ui")) {
                    FieldUi fieldUi = UiComponentUtils.readFieldUi(element, messageHandler, "field-ui");
                    if (fieldUi != null) {
                        uiComponentsBuilder.addUiComponent(fieldUi);
                    }
                } else if (tagName.equals("subset-ui")) {
                    IncludeUi includeUi = UiComponentUtils.readSubsetIncludeUi(element, messageHandler, "subset-ui");
                    if (includeUi != null) {
                        uiComponentsBuilder.addUiComponent(includeUi);
                    }
                } else if (tagName.equals("special-ui")) {
                    IncludeUi includeUi = UiComponentUtils.readSpecialIncludeUi(element, messageHandler, "special-ui");
                    if (includeUi != null) {
                        uiComponentsBuilder.addUiComponent(includeUi);
                    }
                } else {
                    DomMessages.unknownTagWarning(messageHandler, tagName);
                }
            }
        }
    }

    private void readMetadata(Element element_xml) {
        NodeList liste = element_xml.getChildNodes();
        for (int i = 0; i < liste.getLength(); i++) {
            if (liste.item(i).getNodeType() == Node.ELEMENT_NODE) {
                Element element = (Element) liste.item(i);
                String tagName = element.getTagName();
                if (tagName.equals("comment-def")) {
                    CommentUi commentUi = UiComponentUtils.readCommentUi(element, trustedHtmlFactory, messageHandler, "comment-def");
                    if (commentUi != null) {
                        commentUiMap.put(commentUi.getCommentName(), commentUi);
                    }
                } else {
                    DomMessages.unknownTagWarning(messageHandler, tagName);
                }
            }
        }
    }

}
