/* BdfServer_Commands - Copyright (c) 2015-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.addenda;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.NoRemoveableSubsetException;
import net.fichotheque.SubsetKey;
import net.fichotheque.addenda.Addenda;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class AddendaRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "AddendaRemove";
    public final static String COMMANDKEY = "_ ADD-04";
    private Addenda addenda;

    public AddendaRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ADDENDA + "/" + COMMANDNAME);
        SubsetKey addendaKey = addenda.getSubsetKey();
        try {
            editSession.getFichothequeEditor().removeAddenda(addenda);
            setDone("_ done.addenda.addendaremove", addendaKey.getSubsetName());
            putResultObject(SUBSETKEY_OBJ, addendaKey);
        } catch (NoRemoveableSubsetException nrse) {
            throw new ShouldNotOccurException("test done before");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        addenda = BdfInstructionUtils.getMandatoryAddenda(fichotheque, requestMap);
        if (!BdfInstructionUtils.checkConfirmation(requestMap, bdfServer)) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        if (!FichothequeUtils.isRemoveable(addenda)) {
            setError("_ error.notremoveable.addenda");
            return false;
        }
        return true;
    }

}
