/* BdfServer_Commands - Copyright (c) 2010-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.sphere;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.ExistingSubsetException;
import net.fichotheque.SubsetKey;
import net.fichotheque.sphere.SphereEditor;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class SphereCreationCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "SphereCreation";
    public final static String COMMANDKEY = "_ SPH-01";
    public final static String NEWSPHERE_PARAMNAME = "newsphere";
    private SubsetKey sphereKey;

    public SphereCreationCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.SPHERE + "/" + COMMANDNAME);
        try {
            SphereEditor sphereEditor = editSession.getFichothequeEditor().createSphere(sphereKey);
            setDone("_ done.sphere.spherecreation", sphereKey.toString());
            putResultObject(SPHERE_OBJ, sphereEditor.getSphere());
        } catch (ExistingSubsetException ese) {
            throw new ShouldNotOccurException("test before ExistingSubsetException");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        String nameParam = getMandatory(NEWSPHERE_PARAMNAME);
        nameParam = nameParam.trim();
        if (nameParam.length() == 0) {
            setError("_ error.empty.spherename");
            return false;
        }
        try {
            sphereKey = SubsetKey.parse(SubsetKey.CATEGORY_SPHERE, nameParam);
        } catch (java.text.ParseException pe) {
            setError("_ error.wrong.spherename", nameParam);
            return false;
        }
        if (fichotheque.getSubset(sphereKey) != null) {
            setError("_ error.existing.sphere", nameParam);
            return false;
        }
        return true;
    }

}
