/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.text.ParseException;
import net.fichotheque.ExistingIdException;
import net.fichotheque.SubsetKey;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.ThesaurusEditor;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class IdalphaChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "IdalphaChange";
    public final static String COMMANDKEY = "_ THS-09";
    public final static String IDALPHA_PARAMNAME = "idalpha";
    private Motcle motcle;
    private String newIdalpha;

    public IdalphaChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        ThesaurusEditor thesaurusEditor = editSession.getFichothequeEditor().getThesaurusEditor(motcle.getThesaurus().getSubsetKey());
        try {
            boolean done = thesaurusEditor.setIdalpha(motcle, newIdalpha);
            if (done) {
                setDone("_ done.thesaurus.idalphachange");
            }
        } catch (ExistingIdException | ParseException eia) {
            throw new ShouldNotOccurException("test done before");
        }
        putResultObject(THESAURUS_OBJ, motcle.getThesaurus());
        putResultObject(MOTCLE_OBJ, motcle);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        motcle = BdfInstructionUtils.getMandatoryMotcle(fichotheque, requestMap);
        Thesaurus thesaurus = motcle.getThesaurus();
        checkSubsetAdminPermission(thesaurus);
        if (!ThesaurusUtils.isIdalphaType(thesaurus)) {
            throw new BdfInstructionException(BdfInstructionUtils.unsupportedParameterValue(SubsetKey.CATEGORY_THESAURUS_STRING, thesaurus.getSubsetKey().getSubsetName()));
        }
        newIdalpha = getMandatory(IDALPHA_PARAMNAME);
        newIdalpha = StringUtils.cleanString(newIdalpha);
        if (newIdalpha.length() == 0) {
            setError("_ error.empty.idalpha");
            return false;
        }
        if (!ThesaurusUtils.isValidIdalpha(newIdalpha)) {
            setError("_ error.wrong.idalpha", newIdalpha);
            return false;
        }
        Motcle other = thesaurus.getMotcleByIdalpha(newIdalpha);
        if (other != null) {
            setError("_ error.existing.idalpha", newIdalpha);
            return false;
        }
        return true;
    }

}
