/* BdfServer_HtmlProducers - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.corpus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.InteractionConstants;
import fr.exemole.bdfserver.api.interaction.domains.CorpusDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.ui.IncludeUi;
import fr.exemole.bdfserver.api.ui.UiComponents;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfHtmlUtils;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.consumers.PageUnit;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import net.fichotheque.FichothequeConstants;
import net.fichotheque.corpus.Corpus;
import net.mapeadores.util.html.CommandBox;


/**
 *
 * @author Vincent Calame
 */
public class IncludeSpecialFormHtmlProducer extends BdfServerHtmlProducer {

    private final PermissionSummary permissionSummary;
    private final Corpus corpus;

    public IncludeSpecialFormHtmlProducer(ProducerParameters producerParameters, Corpus corpus) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), producerParameters.getPermissionSummary(), corpus);
    }

    public IncludeSpecialFormHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, PermissionSummary permissionSummary, Corpus corpus) {
        super(bdfServer, bdfUser);
        addJsLib(CommonJsLibs.COMMANDTEST);
        addJsLib(CommonJsLibs.DEPLOY);
        addJsLib(CommonJsLibs.SUBSETCHANGE);
        addJsLib(CommonJsLibs.CODEMIRRORMODE);
        addThemeCss("corpus.css");
        this.permissionSummary = permissionSummary;
        this.corpus = corpus;
    }

    @Override
    public void printHtml() {
        UiComponents uiComponents = bdfServer.getUiManager().getMainUiComponents(corpus);
        start();
        BdfHtmlUtils.printSubsetHeader(this, bdfServer, bdfUser, permissionSummary, corpus, CorpusDomain.INCLUDE_SPECIALFORM_PAGE);
        CorpusHtmlUtils.printCorpusToolbar(this, corpus, CorpusDomain.INCLUDE_SPECIALFORM_PAGE);
        printCommandMessageUnit();
        CommandBox commandBox = CommandBox.init()
                .action(Domains.CORPUS)
                .family("CRP")
                .page(CorpusDomain.INCLUDE_SPECIALFORM_PAGE)
                .mode(InteractionConstants.SUBUNIT_MODE);
        this
                .__(PageUnit.start("action-Special", "_ link.corpus.corpusinclude_specialform"))
                .DL("global-DL")
                .__(printSpecial(uiComponents, commandBox, FichothequeConstants.LIAGE_NAME))
                .__(printSpecial(uiComponents, commandBox, FichothequeConstants.RATTACHEMENT_NAME))
                ._DL()
                .__(PageUnit.END);
        end();
    }

    private boolean printSpecial(UiComponents componentUiHolder, CommandBox commandBox, String name) {
        IncludeUi includeUi = (IncludeUi) componentUiHolder.getUiComponent(name);
        if (includeUi != null) {
            this
                    .DT()
                    .__(BdfHtmlUtils.printSpecialCodeMirrorSpan(this, includeUi, bdfServer, workingLang))
                    ._DT()
                    .DD()
                    .__(CorpusHtmlUtils.printIncludeChangeDetails(this, commandBox, corpus, includeUi, bdfServer.getLangConfiguration().getWorkingLangs(), isWithJavascript()))
                    ._DD();
        }
        return true;
    }

}
