/* BdfServer_HtmlProducers - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.pioche;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.GeoJsLibs;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.JsObject;
import net.mapeadores.util.primitives.DegreDecimal;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class GeocodageHtmlProducer extends BdfServerHtmlProducer {

    private final static String[] EMPTY_ARRAY = new String[0];
    private final DegreDecimal latDecimal;
    private final DegreDecimal lonDecimal;
    private final String appelant;
    private final String[] addressArray;

    public GeocodageHtmlProducer(ProducerParameters producerParameters, PiocheParameters piocheParameters) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), piocheParameters);
    }

    public GeocodageHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, PiocheParameters piocheParameters) {
        super(bdfServer, bdfUser);
        appelant = piocheParameters.getAppelant();
        latDecimal = (DegreDecimal) piocheParameters.getParameter(PiocheParameters.LAT);
        lonDecimal = (DegreDecimal) piocheParameters.getParameter(PiocheParameters.LON);
        String adressFields = (String) piocheParameters.getParameter(PiocheParameters.ADRESSFIELDS);
        if (adressFields != null) {
            addressArray = StringUtils.getTechnicalTokens(adressFields, true);
        } else {
            addressArray = EMPTY_ARRAY;
        }
        addThemeCss("geocodage.css");
        addJsLib(GeoJsLibs.PIOCHE);
    }

    @Override
    public void printHtml() {
        String latitudeId;
        String longitudeId;
        int idx = appelant.indexOf(',');
        if (idx > 0) {
            latitudeId = appelant.substring(0, idx);
            longitudeId = appelant.substring(idx + 1);
        } else {
            latitudeId = appelant;
            longitudeId = "";
        }
        String clientId = generateId();
        JsObject piocheArgs = JsObject.init()
                .put("clientId", clientId)
                .put("latitudeId", latitudeId)
                .put("longitudeId", longitudeId)
                .put("addressArray", addressArray);
        if ((latDecimal != null) && (lonDecimal != null)) {
            piocheArgs.put("start", JsObject.init()
                    .put("latitude", latDecimal.toString())
                    .put("longitude", lonDecimal.toString()));
        }
        startLoc("_ title.pioche.geocodage");
        this
                .SCRIPT()
                .__jsObject("Geo.Geocodage.ARGS", piocheArgs)
                ._SCRIPT();
        this
                .DIV(HA.id(clientId).classes("geocodage-Client"))
                ._DIV();
        end();
    }

}
