/* BdfServer_HtmlProducers - Copyright (c) 2010-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.sphere;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.SphereDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfHtmlUtils;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.jslib.CommonJsLibs;
import net.fichotheque.sphere.Sphere;
import net.mapeadores.util.html.CommandBox;


/**
 *
 * @author Vincent Calame
 */
public class RedacteurCreationFormHtmlProducer extends BdfServerHtmlProducer {

    private final PermissionSummary permissionSummary;
    private final Sphere sphere;

    public RedacteurCreationFormHtmlProducer(ProducerParameters producerParameters, Sphere sphere) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), producerParameters.getPermissionSummary(), sphere);
    }

    public RedacteurCreationFormHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, PermissionSummary permissionSummary, Sphere sphere) {
        super(bdfServer, bdfUser);
        addJsLib(CommonJsLibs.COMMANDTEST);
        this.permissionSummary = permissionSummary;
        this.sphere = sphere;
    }

    @Override
    public void printHtml() {
        start();
        BdfHtmlUtils.printSubsetHeader(this, bdfServer, bdfUser, permissionSummary, sphere, SphereDomain.REDACTEUR_CREATIONFORM_PAGE);
        printCommandMessageUnit();
        CommandBox commandBox = CommandBox.init()
                .action(Domains.SPHERE)
                .family("SPH")
                .page(SphereDomain.REDACTEUR_ADMINFORM_PAGE);
        SphereCommandBoxUtils.printRedacteurCreationBox(this, commandBox, sphere);
        end();
    }

}
