/* global BDF,$$,TableExport,Overlay */

TableExport.Overlay = {};


TableExport.Overlay.showTableExportCreationForm = function () {
    if (!BDF.confirmUnload()) {
        return;
    }
    var corpusOptions = TableExport.Overlay.toOptions(TableExport.subsetTrees.getSubsetTree("corpus"), false, false);
    var thesaurusOptions = TableExport.Overlay.toOptions(TableExport.subsetTrees.getSubsetTree("thesaurus"), false, false);
    var submitId = BDF.generateId();
    var corpusSelectId = BDF.generateId();
    var thesaurusSelectId = BDF.generateId();
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-11"),
        content: BDF.render("tableexport:overlay-tableexportcreationform", {
            corpusOptionsHtml: corpusOptions.html,
            thesaurusOptionsHtml: thesaurusOptions.html,
            corpusSelectId: corpusSelectId,
            thesaurusSelectId: thesaurusSelectId,
            commandKey: "EXP-11",
            commandUrl: BDF.getCommandUrl("EXP-11")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.creation',
                id: submitId,
                disabled: true
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    BDF.Pane.clearMain();
                    Overlay.end($form, function () {
                        BDF.showCommandMessage(data.commandMessage);
                        TableExport.insertTableExport(data.tableExport);
                    });
                }
            }
        },
        afterStart: function ($overlayDialog) {
            $$(corpusSelectId).change(_testSubsetListSelection);
            $$(thesaurusSelectId).change(_testSubsetListSelection);
        }
    });
    
    
    function _testSubsetListSelection () {
        var count = $( "#" + corpusSelectId + " :selected").length +  $( "#" + thesaurusSelectId + " :selected").length;
        $$(submitId).prop("disabled", (count === 0));
    }
    
};

TableExport.Overlay.showContentRemoveConfirm = function (tableExportName, contentPath) {
    var tableExport = TableExport.getTableExport(tableExportName);
    if (!tableExport) {
        return;
    }
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-16"),
        content: BDF.render("tableexport:overlay-contentremoveconfirm", {
            tableExportName: tableExportName,
            title: tableExport.title,
            contentPath: contentPath,
            commandKey: "EXP-16",
            commandUrl: BDF.getCommandUrl("EXP-16")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.contentremove'
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    Overlay.end($form, function () {
                        BDF.Pane.clearMain();
                        BDF.showCommandMessage(data.commandMessage);
                        TableExport.updateTableExport(data.tableExport);
                    });
                }
            }
        }
    });
};

TableExport.Overlay.showTableExportRemoveConfirm = function (tableExportName) {
    if (!BDF.confirmUnload()) {
        return;
    }
    var tableExport = TableExport.getTableExport(tableExportName);
    if (!tableExport) {
        return;
    }
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-12"),
        content: BDF.render("tableexport:overlay-tableexportremoveconfirm", {
            tableExportName: tableExportName,
            title: tableExport.title,
            commandKey: "EXP-12",
            commandUrl: BDF.getCommandUrl("EXP-12")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.remove'
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    Overlay.end($form, function () {
                        BDF.showCommandMessage(data.commandMessage);
                        TableExport.removeTableExport(tableExportName);
                    });
                }
            }
        }
    });
};

TableExport.Overlay.showTableExportCopyForm = function (tableExportName) {
    if (!BDF.confirmUnload()) {
        return;
    }
    var tableExport = TableExport.getTableExport(tableExportName);
    if (!tableExport) {
        return;
    }
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-18"),
        content: BDF.render("tableexport:overlay-tableexportcopyform", {
            tableExportName: tableExportName,
            title: tableExport.title,
            commandKey: "EXP-18",
            commandUrl: BDF.getCommandUrl("EXP-18")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.copy'
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    BDF.Pane.clearMain();
                    Overlay.end($form, function () {
                        BDF.showCommandMessage(data.commandMessage);
                        TableExport.insertTableExport(data.tableExport);
                    });
                }
            }
        }
    });
};

TableExport.Overlay.showCorpusContentCreationForm = function (tableExportName) {
    if (!BDF.confirmUnload()) {
        return;
    }
    var tableExport = TableExport.getTableExport(tableExportName);
    if (!tableExport) {
        return;
    }
    var corpusOptions = TableExport.Overlay.toOptions(TableExport.subsetTrees.getSubsetTree("corpus"), true, TableExport.List.getExistingSubsetKeySet(tableExportName));
    var disabled = (corpusOptions.count === 0);
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-14"),
        content: BDF.render("tableexport:overlay-corpuscontentcreationform", {
            tableExportName: tableExportName,
            title: tableExport.title,
            disabled: disabled,
            optionsHtml: corpusOptions.html,
            commandKey: "EXP-14",
            commandUrl: BDF.getCommandUrl("EXP-14")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.corpuscontentcreation',
                disabled: disabled
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    let valueArray = data.commandMessage.values;
                    let contentPath = valueArray[1] + ".txt";
                    TableExport.updateTableExport(data.tableExport);
                    BDF.Pane.clearMain();
                    BDF.Ajax.loadTableExportContent(tableExportName, contentPath, function (tableExportContent) {
                        TableExport.ContentForm.load(tableExportContent, false);
                        Overlay.end($form, function () {
                            BDF.showCommandMessage(data.commandMessage);
                        });
                    });
                }
            }
        }
    });
};

TableExport.Overlay.showThesaurusContentCreationForm = function (tableExportName) {
    if (!BDF.confirmUnload()) {
        return;
    }
    var tableExport = TableExport.getTableExport(tableExportName);
    if (!tableExport) {
        return;
    }
    var thesaurusOptions = TableExport.Overlay.toOptions(TableExport.subsetTrees.getSubsetTree("thesaurus"), true, TableExport.List.getExistingSubsetKeySet(tableExportName));
    var disabled = (thesaurusOptions.count === 0);
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-15"),
        content: BDF.render("tableexport:overlay-thesauruscontentcreationform", {
            tableExportName: tableExportName,
            title: tableExport.title,
            disabled: disabled,
            optionsHtml: thesaurusOptions.html,
            commandKey: "EXP-15",
            commandUrl: BDF.getCommandUrl("EXP-15")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.tableexport.thesauruscontentcreation',
                disabled: disabled
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                let done = BDF.Ajax.checkError(data);
                if (done) {
                    let valueArray = data.commandMessage.values;
                    let contentPath = valueArray[1] + ".txt";
                    BDF.Pane.clearMain();
                    TableExport.updateTableExport(data.tableExport);
                    BDF.Ajax.loadTableExportContent(tableExportName, contentPath, function (tableExportContent) {
                        TableExport.ContentForm.load(tableExportContent, false);
                        Overlay.end($form, function () {
                            BDF.showCommandMessage(data.commandMessage);
                        });
                    });
                }
            }
        }
    });
};
    
TableExport.Overlay.showTableTest = function (tableExportName, contentPath) {
    var dataDestinationId = BDF.generateId();
    var subsetKeyObj = TableExport.parseSubsetKey(contentPath);
    Overlay.start({
            header: BDF.Loc.escape("_ title.tableexport.tabletest"),
            content: BDF.render("tableexport:overlay-tabletest", {
                dataDestinationId: dataDestinationId
            }),
            isWaiting: true,
            afterStart: function ($overlayDialog, waitingCallback) {
                $.ajax ({
                    url: "tables/get-htmlfragment",
                    data: {
                        tableexport: tableExportName,
                        subset: subsetKeyObj.subsetKey,
                        type: "echantillon",
                        header: "keyheader"
                    },
                    dataType: "html",
                    success: function (data) {
                        $$(dataDestinationId).html(data);
                        waitingCallback();
                     }
                 });
            }
    });
    
};


TableExport.Overlay.toOptions = function (rootNodeArray, withWholeKey, existingSubsetKeySet) {
    var options = {
        count: 0,
        html: ""
    };
    _convert(rootNodeArray, 0);
    return options;
    
    
    function _convert(nodeArray, level) {
        for(var i = 0, len = nodeArray.length; i < len; i++) {
            var obj = nodeArray[i];
            var nodeType = obj.node;
            if (nodeType === "group") {
                _append("<optgroup label='");
                for(var j = 0; j < level; j++) {
                    _append("&nbsp; &nbsp; ");
                }
                _append(obj.title);
                _append("'>");
                _append("</optgroup>");
                _convert(obj.array, level + 1);
            } else if (nodeType === "subset") {
                _append("<option value='");
                if (withWholeKey) {
                    _append(obj.key);
                } else {
                    _append(obj.name);
                }
                _append("'");
                if ((existingSubsetKeySet) && (existingSubsetKeySet[obj.key])) {
                    _append(" disabled='disabled'");
                } else {
                    _increase();
                }
                _append(">");
                for(var j = 0; j < level; j++) {
                    _append("&nbsp; &nbsp; ");
                }
                if (obj.title) {
                    _append(obj.title);
                } else {
                    _append(obj.name);
                }
                _append(" [");
                _append(obj.name);
                _append("]");
                _append("</option>");
            }
        }
    }
    
    
    function _increase() {
        options.count++;
    }
    
    
    function _append(html) {
        options.html += html;
    }
    
};