/* FichothequeLib_Tools - Copyright (c) 2013-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.dom;

import java.text.ParseException;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.thesaurus.ThesaurusEditor;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class MotcleDOMReader {

    private final MessageHandler messageHandler;
    private final ThesaurusEditor thesaurusEditor;
    private final AttributeDOMReader attributeDOMReader;
    private final RootHandler rootHandler = new RootHandler();

    public MotcleDOMReader(ThesaurusEditor thesaurusEditor, MessageHandler messageHandler) {
        this.thesaurusEditor = thesaurusEditor;
        this.messageHandler = messageHandler;
        this.attributeDOMReader = new AttributeDOMReader(thesaurusEditor.getFichothequeEditor(), messageHandler);
    }

    public void fillMotcle(Motcle motcle, Element element) {
        rootHandler.setMotcle(motcle);
        DOMUtils.readChildren(element, rootHandler);
    }


    private class RootHandler implements ElementHandler {

        private Motcle motcle;

        private RootHandler() {
        }

        private void setMotcle(Motcle motcle) {
            this.motcle = motcle;
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if ((tagName.equals("label")) || (tagName.equals("lib"))) {
                try {
                    Label label = LabelUtils.readLabel(element);
                    if (label != null) {
                        thesaurusEditor.putLabel(motcle, label);
                    }
                } catch (ParseException e) {
                    DomMessages.wrongLangAttribute(messageHandler, "lib", element.getAttribute("xml:lang"));
                }
            } else if (tagName.equals("attr")) {
                attributeDOMReader.readAttrElement(element, motcle, tagName);
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
