/* FichothequeLib_Tools - Copyright (c) 2013-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.dom;

import java.text.ParseException;
import java.util.LinkedHashSet;
import java.util.Set;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadata;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadataEditor;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.Langs;
import net.mapeadores.util.localisation.LangsUtils;
import net.mapeadores.util.logging.MessageHandler;
import net.mapeadores.util.xml.DOMUtils;
import net.mapeadores.util.xml.DomMessages;
import net.mapeadores.util.xml.ElementHandler;
import net.mapeadores.util.xml.XMLUtils;
import org.w3c.dom.Element;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusMetadataDOMReader extends AbstractMetadataDOMReader {

    private final ThesaurusMetadataEditor thesaurusMetadataEditor;

    public ThesaurusMetadataDOMReader(ThesaurusMetadataEditor thesaurusMetadataEditor, MessageHandler messageHandler) {
        super(thesaurusMetadataEditor, messageHandler, "thesaurus");
        this.thesaurusMetadataEditor = thesaurusMetadataEditor;
    }

    public static short getThesaurusType(Element element) {
        String typeString = element.getAttribute("thesaurus-type");
        return ThesaurusUtils.thesaurusTypeToShort(typeString);
    }

    public void fillMetadata(Element element) {
        if (((ThesaurusMetadata) thesaurusMetadataEditor.getMetadata()).getThesaurusType() != ThesaurusMetadata.BABELIEN_TYPE) {
            String langsString = element.getAttribute("thesaurus-langs");
            if (langsString.length() > 0) {
                Langs langs = LangsUtils.toCleanLangs(langsString);
                if (langs.size() > 0) {
                    thesaurusMetadataEditor.setAuthorizedLangs(langs);
                } else {
                    DomMessages.wrongAttributeValue(messageHandler, element.getTagName(), "thesaurus-langs", langsString);
                }
            }
        }
        RootHandler rootHandler = new RootHandler("/" + element.getTagName());
        DOMUtils.readChildren(element, rootHandler);
        rootHandler.flush();
    }


    private class RootHandler implements ElementHandler {

        private final Set<Lang> langSet = new LinkedHashSet();
        private final String parentXpath;

        private RootHandler(String parentXpath) {
            this.parentXpath = parentXpath;
        }

        @Override
        public void readElement(Element element) {
            if (readCommonElement(element, parentXpath)) {
                return;
            }
            String tagName = element.getTagName();
            String xpath = parentXpath + "/" + tagName;
            if (tagName.equals("langs")) {
                LangsHandler langsHandler = new LangsHandler(langSet);
                DOMUtils.readChildren(element, langsHandler);
            } else {
                DomMessages.unknownTagWarning(messageHandler, xpath);
            }
        }

        private void flush() {
            Langs langs = LangsUtils.fromCollection(langSet);
            if (langs.size() > 0) {
                thesaurusMetadataEditor.setAuthorizedLangs(langs);
            }
        }

    }


    private class LangsHandler implements ElementHandler {

        private final Set<Lang> langSet;

        private LangsHandler(Set<Lang> langSet) {
            this.langSet = langSet;
        }

        @Override
        public void readElement(Element element) {
            String tagName = element.getTagName();
            if (tagName.equals("lang")) {
                String text = XMLUtils.getData(element);
                try {
                    Lang lang = Lang.parse(text);
                    langSet.add(lang);
                } catch (ParseException pe) {
                    DomMessages.wrongElementValue(messageHandler, tagName, text);
                }
            } else {
                DomMessages.unknownTagWarning(messageHandler, tagName);
            }
        }

    }

}
