/* FichothequeLib_Tools - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.ArrayList;
import java.util.List;
import net.fichotheque.extraction.ExtractionConstants;
import static net.fichotheque.extraction.ExtractionConstants.EXTRACTION_DEFAULT_TAGNAME;
import static net.fichotheque.extraction.ExtractionConstants.STATIC_DEFAULT_TAGNAME;
import net.fichotheque.extraction.def.ExtractionDef;
import net.fichotheque.extraction.def.ExtraitCorpusDef;
import net.fichotheque.extraction.def.ExtraitThesaurusDef;


/**
 *
 * @author Vincent Calame
 */
public class ExtractionDefBuilder implements ExtractionConstants {

    private ExtraitCorpusDef dynamicExtraitCorpusDef;
    private ExtraitThesaurusDef dynamicExtraitThesaurusDef;
    private String tagName = EXTRACTION_DEFAULT_TAGNAME;
    private String staticTagName = STATIC_DEFAULT_TAGNAME;
    private final List<ExtraitCorpusDef> staticExtraitCorpusDefList = new ArrayList<ExtraitCorpusDef>();
    private final List<ExtraitThesaurusDef> staticExtraitThesaurusDefList = new ArrayList<ExtraitThesaurusDef>();

    public ExtractionDefBuilder() {
    }

    public ExtractionDefBuilder setDynamicExtraitCorpusDef(ExtraitCorpusDef extraitCorpusDef) {
        this.dynamicExtraitCorpusDef = extraitCorpusDef;
        return this;
    }

    public ExtractionDefBuilder setDynamicExtraitThesaurusDef(ExtraitThesaurusDef extraitThesaurusDef) {
        this.dynamicExtraitThesaurusDef = extraitThesaurusDef;
        return this;
    }

    public ExtractionDefBuilder setTagName(String tagName) {
        this.tagName = BuilderUtils.testTagName(tagName, EXTRACTION_DEFAULT_TAGNAME);
        return this;
    }

    public ExtractionDefBuilder setStaticTagName(String staticTagName) {
        this.staticTagName = BuilderUtils.testTagName(staticTagName, STATIC_DEFAULT_TAGNAME);
        return this;
    }

    public ExtractionDefBuilder addStatic(ExtraitCorpusDef extraitCorpusDef) {
        this.staticExtraitCorpusDefList.add(extraitCorpusDef);
        return this;
    }

    public ExtractionDefBuilder addStatic(ExtraitThesaurusDef extraitThesaurusDef) {
        this.staticExtraitThesaurusDefList.add(extraitThesaurusDef);
        return this;
    }

    public ExtractionDef toExtractionDef() {
        return new InternalExtractionDef(dynamicExtraitCorpusDef, dynamicExtraitThesaurusDef, tagName, staticExtraitCorpusDefList, staticExtraitThesaurusDefList, staticTagName);
    }

    public static ExtractionDefBuilder init() {
        return new ExtractionDefBuilder();
    }


    private static class InternalExtractionDef implements ExtractionDef {

        private final ExtraitCorpusDef dynamicExtraitCorpusDef;
        private final ExtraitThesaurusDef dynamicExtraitThesaurusDef;
        private final String tagName;
        private final String staticTagName;
        private final List<ExtraitCorpusDef> staticExtraitCorpusDefList;
        private final List<ExtraitThesaurusDef> staticExtraitThesaurusDefList;

        private InternalExtractionDef(ExtraitCorpusDef dynamicExtraitCorpusDef, ExtraitThesaurusDef dynamicExtraitThesaurusDef, String tagName, List<ExtraitCorpusDef> staticExtraitCorpusDefList, List<ExtraitThesaurusDef> staticExtraitThesaurusDefList, String staticTagName) {
            this.dynamicExtraitCorpusDef = dynamicExtraitCorpusDef;
            this.dynamicExtraitThesaurusDef = dynamicExtraitThesaurusDef;
            this.tagName = tagName;
            this.staticExtraitCorpusDefList = staticExtraitCorpusDefList;
            this.staticExtraitThesaurusDefList = staticExtraitThesaurusDefList;
            this.staticTagName = staticTagName;
        }

        @Override
        public ExtraitCorpusDef getDynamicExtraitCorpusDef() {
            return dynamicExtraitCorpusDef;
        }

        @Override
        public ExtraitThesaurusDef getDynamicExtraitThesaurusDef() {
            return dynamicExtraitThesaurusDef;
        }

        @Override
        public String getTagName() {
            return tagName;
        }

        @Override
        public List<ExtraitCorpusDef> getStaticExtraitCorpusDefList() {
            return staticExtraitCorpusDefList;
        }

        @Override
        public List<ExtraitThesaurusDef> getStaticExtraitThesaurusDefList() {
            return staticExtraitThesaurusDefList;
        }

        @Override
        public String getStaticTagName() {
            return staticTagName;
        }

    }

}
