/* FichothequeLib_Xml - Copyright (c) 2011-2017 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.xml.extraction;

import java.io.IOException;
import java.util.List;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.extraction.def.ExtraitThesaurusDef;
import net.fichotheque.extraction.run.ExtraitThesaurusResult;
import net.fichotheque.extraction.run.MotcleExtractInfo;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.LangContext;
import net.mapeadores.util.localisation.ListLangContext;
import net.mapeadores.util.localisation.UserLangContext;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.xml.XMLPart;
import net.mapeadores.util.xml.XMLUtils;
import net.mapeadores.util.xml.XMLWriter;


/**
 *
 * @author Vincent Calame
 */
public class ExtraitThesaurusXMLPart extends XMLPart {

    private final ExtractionContext extractionContext;
    private final MotcleXMLPart motcleXMLPart;

    public ExtraitThesaurusXMLPart(XMLWriter xmlWriter, ExtractionContext extractionContext) {
        super(xmlWriter);
        this.extractionContext = extractionContext;
        motcleXMLPart = new MotcleXMLPart(xmlWriter, extractionContext);
    }

    public void addExtraitThesaurus(ExtraitThesaurusResult extraitThesaurusResult) throws IOException {
        ExtraitThesaurusDef extraitThesaurusDef = extraitThesaurusResult.getExtraitThesaurusDef();
        String tagName = extraitThesaurusDef.getTagName();
        boolean withTag = (tagName != null);
        int thesaurusCount = extraitThesaurusResult.getThesaurusCount();
        String extraitName = extraitThesaurusDef.getExtraitName();
        if (extraitName != null) {
            if (withTag) {
                startOpenTag(tagName);
                addAttribute("extrait-name", extraitName);
                endOpenTag();
            }
            for (int j = 0; j < thesaurusCount; j++) {
                List<MotcleExtractInfo> list = extraitThesaurusResult.getMotcleExtractInfoList(j);
                for (MotcleExtractInfo motcleExtractInfo : list) {
                    motcleXMLPart.addMotcle(motcleExtractInfo);
                }
            }
            if (withTag) {
                closeTag(tagName);
            }
        } else {
            boolean withThesaurusTitle = extraitThesaurusDef.getMotcleFilter().isWithThesaurusTitle();
            LangContext langContext = extractionContext.getLangContext();
            for (int j = 0; j < thesaurusCount; j++) {
                Thesaurus thesaurus = extraitThesaurusResult.getThesaurus(j);
                if (withTag) {
                    startOpenTag(tagName);
                    addAttribute("thesaurus", thesaurus.getSubsetKey().getSubsetName());
                    endOpenTag();
                }
                List<MotcleExtractInfo> list = extraitThesaurusResult.getMotcleExtractInfoList(j);
                for (MotcleExtractInfo motcleExtractInfo : list) {
                    motcleXMLPart.addMotcle(motcleExtractInfo);
                }
                if (withThesaurusTitle) {
                    openTag("intitule");
                    if (langContext instanceof ListLangContext) {
                        for (ListLangContext.Unit unit : (ListLangContext) langContext) {
                            Lang lang = unit.getLang();
                            String title = FichothequeUtils.getTitle(thesaurus, lang);
                            XMLUtils.addLibElement(this, lang, title);
                            LabelUtils.addLabel(this, lang, title);
                        }
                    } else if (langContext instanceof UserLangContext) {
                        UserLangContext userLangContext = (UserLangContext) langContext;
                        Lang workingLang = userLangContext.getWorkingLang();
                        String title = FichothequeUtils.getTitle(thesaurus, workingLang);
                        XMLUtils.addLibElement(this, null, title);
                        LabelUtils.addLabel(this, null, title);
                    }
                    closeTag("intitule");
                }
                if (withTag) {
                    closeTag(tagName);
                }
            }
        }
    }

}
